#!/usr/local/bin/php
<?php
/*
 * pfSense-update-repos.php
 *
 * part of pfSense (https://www.pfsense.org)
 * Copyright (c) 2022 Rubicon Communications, LLC (Netgate)
 * All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

require_once("/etc/inc/config.inc");

function help() {
	global $g;

	echo "{$g['product_name']}-update-repos.php: Update the {$g['product_name']} repository settings.\n";
	echo "\n";
	echo "Options:\n";
	echo "\t-d\tEnable debug.\n";
	echo "\t-h\tThis help text.\n";
	echo "\t-n\tPrint the current repository name.\n";
}

$opts = getopt("dhn");

/*
 * -d	Enable debug.
 * -h	Help text.
 * -n	Print the current repository name (set in pfSense config XML).
 */
if (isset($opts["d"])) {
	$DEBUG = true;
} else {
	$DEBUG = false;
}

/* Help text. */
if (isset($opts["h"])) {
	help();
	exit(0);
}

/*
 * Print the repository name (set in the pfSense config).
 */
if (isset($opts["n"])) {
	require_once("/etc/inc/pkg-utils.inc");
	$config = parse_config();
	echo pkg_get_repo_name($config["system"]["pkg_repo_conf_path"]);
	exit(0);
}

/*
 * Update the pfSense repository settings.
 */

require_once("/usr/local/{$g['product_name']}/include/Netgate/repos/{$g['product_name']}-update-repos.inc.php");

$repos = local_update_repos($DEBUG);

/*
 * Backward compatibility workaround to detect and return correctly when
 * calling the old update_repos() during the upgrade from older versions.
 */
if (!is_array($repos) && $repos === NULL) {
	exit(0);
}

/* Invalid answer. */
if (!is_array($repos)) {
	exit(1);
}
/* Check for messages. */
if (isset($repos['messages']) && is_array($repos['messages'])) {
	foreach ($repos['messages'] as $message) {
		echo "{$message}\n";
	}
}
/* Return the error code. */
if (isset($repos['error'])) {
	exit($repos['error']);
}
/* If no error code is present, that is an error. */
exit(1);

?>
